@@ -24,7 +24,7 @@
 
 #include <QLabel>
 
-#include <kxmlguiwindow.h>
+#include <KXmlGuiWindow>
 #include <game.h>
 
 class QAction;
@@ -51,7 +51,7 @@ public slots:
 
 protected:
   /// To make sure all activity ceases before closing.
-  bool queryClose();
+  bool queryClose() override;
 
 private:
   Game * m_game;
